@@ -2,8 +2,11 @@
 #
 # Purpose: Returns the major release of the operating system.
 #
-# Resolution: splits down the operatingsystemrelease fact at decimal point for
-#  osfamily RedHat derivatives and Debian.
+# Resolution:
+#   Splits down the operatingsystemrelease fact at decimal point for
+#   osfamily RedHat derivatives and Debian.
+#   Uses operatingsystemrelease to the first non decimal character for
+#   operatingsystem Solaris
 #
 # This should be the same as lsbmajdistrelease, but on minimal systems there
 # are too many dependencies to use LSB
@@ -13,6 +16,7 @@
 #"Debian" "Fedora" "Gentoo" "Mandrake" "Mandriva" "MeeGo" "OEL" "OpenSuSE" 
 #"OracleLinux" "OVS" "PSBM" "RedHat" "Scientific" "Slackware" "Slamd64" "SLC"
 #"SLED" "SLES" "SuSE" "Ubuntu" "VMWareESX"
+
 Facter.add(:operatingsystemmajrelease) do
   confine :operatingsystem => [
     :Amazon,
@@ -31,3 +35,12 @@ Facter.add(:operatingsystemmajrelease) do
     Facter.value('operatingsystemrelease').split('.').first
   end
 end
+
+Facter.add(:operatingsystemmajrelease) do
+  confine :operatingsystem => :solaris
+  setcode do
+    if match = Facter.value(:operatingsystemrelease).match(/^(\d+)/)
+      match.captures[0]
+    end
+  end
+end
