@@ -185,35 +185,35 @@ describe "Processor facts" do
 
     it "should be 2 on dual-processor Darwin box" do
       Facter.fact(:kernel).stubs(:value).returns("Darwin")
-      Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.ncpu", anything).returns('2')
+      Facter::Core::Execution.stubs(:execute).with("sysctl -n hw.ncpu", anything).returns('2')
 
       Facter.fact(:processorcount).value.should == "2"
     end
 
     it "should be 2 on dual-processor OpenBSD box" do
       Facter.fact(:kernel).stubs(:value).returns("OpenBSD")
-      Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.ncpu", anything).returns('2')
+      Facter::Core::Execution.stubs(:execute).with("sysctl -n hw.ncpu", anything).returns('2')
 
       Facter.fact(:processorcount).value.should == "2"
     end
 
     it "should be 2 on dual-processor FreeBSD box" do
       Facter.fact(:kernel).stubs(:value).returns("FreeBSD")
-      Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.ncpu", anything).returns('2')
+      Facter::Core::Execution.stubs(:execute).with("sysctl -n hw.ncpu", anything).returns('2')
 
       Facter.fact(:processorcount).value.should == "2"
     end
 
     it "should print the correct CPU Model on FreeBSD" do
       Facter.fact(:kernel).stubs(:value).returns("FreeBSD")
-      Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.model", anything).returns('SomeVendor CPU 3GHz')
+      Facter::Core::Execution.stubs(:execute).with("sysctl -n hw.model", anything).returns('SomeVendor CPU 3GHz')
 
       Facter.fact(:processor).value.should == "SomeVendor CPU 3GHz"
     end
 
     it "should be 2 on dual-processor DragonFly box" do
       Facter.fact(:kernel).stubs(:value).returns("DragonFly")
-      Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.ncpu", anything).returns('2')
+      Facter::Core::Execution.stubs(:execute).with("sysctl -n hw.ncpu", anything).returns('2')
 
       Facter.fact(:processorcount).value.should == "2"
     end
